/*
Connections of Drive and Arduino
Serial Port 0 is not used to connect to drive because its connected to USB-Serial and used to show information on console.

For Arduino Uno Software serial needs to be used as there is only one hardware serial port and its connected to USB-Serial. 
   Drive to Arduino UNO/Nano connections
   GND         -      GND
   RXD         -      D3
   TXD         -      D2

For arduino mega and other arduinos with multiple hardware serial port, any port other than 0 can be selected to connect the drive.

   Drive to Arduino Mega2560 connections
   GND         -      GND
   RXD         -      Tx1/Tx2/Tx3
   TXD         -      Rx1/Rx2/Rx3

*  In this mode Speed, Direction, Acceleration can be controlled.
* For more information see :https://robokits.co.in/motor-drives-drivers/dc-motor-driver/rhino-dc-driver-50w-compatible-with-modbus-uart-ascii-for-dc-motor
*/

#include <RMCS2304.h>

RMCS2304 rmcs;  //object for class RMCS2304

SoftwareSerial myserial(2,3);   //Software Serial port  "mandatory for Arduino Uno"

//parameter Settings "Refer datasheet for details"
byte slave_id=7;
int INP_CONTROL_MODE=513;           
int acceleration=1;  // Range of acceleration is 1-128
int speed=1000;      // Range of acceleration is 0-2048

void setup()
{
    rmcs.Serial_selection(1);       //Serial port selection:0-Hardware serial,1-Software serial
    rmcs.Serial0(9600);             //set baudrate for usb serial to monitor data on serial monitor in Arduino IDE
    Serial.println("RMCS-2304 Digital Speed control mode demo\r\n\r\n");
    //rmcs.begin(&Serial1,9600);    //hardware serial port for mega2560:Serial1,Serial2,Serial3 and set baudrate Uncomment this line if hardware serial port
    rmcs.begin(&myserial,9600);     //comment this line if you are using hardware serial port    
    rmcs.WRITE_PARAMETER(slave_id,INP_CONTROL_MODE,acceleration,speed);    
    rmcs.READ_PARAMETER(slave_id); 
}

void loop(void)
{   
   Serial.println("Sending speed command - 1000");
   Serial.println("Motor running in Clock-wise Direction");
   rmcs.Speed(slave_id,1000);                   //Set speed within range of 0-2048.
   rmcs.Enable_Digital_Mode(slave_id,0);        //To enable motor in digital speed control mode. 0-fwd,1-reverse direction. 
   
   delay(5000);
   Serial.println("Break Motor");
   rmcs.Brake_Motor(slave_id,0);                 //Brake motor. 0-fwd,1-reverse direction. 

   delay(2000);
   Serial.println("Changing direction");
   Serial.println("Motor running in Anticlock-wise Direction");
   rmcs.Enable_Digital_Mode(slave_id,1);           //To enable motor in digital speed control mode. 0-fwd,1-reverse direction. 

   delay(5000);
   Serial.println("Disable Motor");
   rmcs.Disable_Digital_Mode(slave_id,1);        //Disable motor in digital speed control mode. 0-fwd,1-reverse direction. 
   delay(3000);                                              
}
